@@ -1,5 +1,5 @@
 //! This crate provides types for [read-only git objects][crate::ObjectRef] backed by bytes provided in git's serialization format
-//! as well as [mutable versions][Object] of these. The latter can be serialized into git's serialization format for objects.
+//! as well as [mutable versions][Object] of these. Both types of objects can be encoded.
 #![forbid(unsafe_code)]
 #![deny(rust_2018_idioms, missing_docs)]
 
@@ -20,6 +20,9 @@ pub mod tree;
 
 mod blob;
 
+mod traits;
+pub use traits::WriteTo;
+
 mod encode;
 pub(crate) mod parse;
 
@@ -148,10 +151,10 @@ pub struct Tag {
     pub target_kind: crate::Kind,
     /// The name of the tag, e.g. "v1.0".
     pub name: BString,
+    /// The tags author.
+    pub tagger: Option<git_actor::Signature>,
     /// The message describing the tag.
     pub message: BString,
-    /// The tags author.
-    pub signature: Option<git_actor::Signature>,
     /// A pgp signature over all bytes of the encoded tag, excluding the pgp signature itself.
     pub pgp_signature: Option<BString>,
 }
